@@ -1,6 +1,5 @@
 """Parse link title
 """
-
 from ..common.utils import unescapeAll, charCodeAt
 
 
@@ -13,8 +12,11 @@ class _Result:
         self.lines = 0
         self.str = ""
 
+    def __str__(self):
+        return self.str
 
-def parseLinkTitle(string, pos, maximum):
+
+def parseLinkTitle(string: str, pos: int, maximum: int) -> _Result:
     lines = 0
     start = pos
     result = _Result()
@@ -37,11 +39,15 @@ def parseLinkTitle(string, pos, maximum):
     while pos < maximum:
         code = charCodeAt(string, pos)
         if code == marker:
+            title = string[start + 1 : pos]
+            title = unescapeAll(title)
             result.pos = pos + 1
             result.lines = lines
-            result.str = unescapeAll(string[start + 1 : pos])
+            result.str = title
             result.ok = True
             return result
+        elif code == 0x28 and marker == 0x29:  # /* ( */  /* ) */
+            return result
         elif code == 0x0A:
             lines += 1
         elif code == 0x5C and pos + 1 < maximum:  # /* \ */
