@@ -1,5 +1,6 @@
 # Block quotes
 import logging
+from typing import Optional
 
 from .state_block import StateBlock
 from ..common.utils import isSpace
@@ -23,7 +24,6 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
 
     # check the block quote marker
     if state.srcCharCode[pos] != 0x3E:  # /* > */
-        pos += 1
         return False
     pos += 1
 
@@ -32,15 +32,16 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
     if silent:
         return True
 
-    # skip spaces after ">" and re-calculate offset
-    initial = offset = (
-        state.sCount[startLine]
-        + pos
-        - (state.bMarks[startLine] + state.tShift[startLine])
-    )
+    # set offset past spaces and ">"
+    initial = offset = state.sCount[startLine] + 1
+
+    try:
+        second_char_code: Optional[int] = state.srcCharCode[pos]
+    except IndexError:
+        second_char_code = None
 
     # skip one optional space after '>'
-    if state.srcCharCode[pos] == 0x20:  # /* space */
+    if second_char_code == 0x20:  # /* space */
         # ' >   test '
         #     ^ -- position start of line here:
         pos += 1
@@ -48,7 +49,7 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
         offset += 1
         adjustTab = False
         spaceAfterMarker = True
-    elif state.srcCharCode[pos] == 0x09:  # /* tab */
+    elif second_char_code == 0x09:  # /* tab */
         spaceAfterMarker = True
 
         if (state.bsCount[startLine] + offset) % 4 == 3:
@@ -104,7 +105,6 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
 
     oldParentType = state.parentType
     state.parentType = "blockquote"
-    wasOutdented = False
 
     # Search the end of the block
     #
@@ -137,8 +137,7 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
         #    > current blockquote
         # 2. checking this line
         # ```
-        if state.sCount[nextLine] < state.blkIndent:
-            wasOutdented = True
+        isOutdented = state.sCount[nextLine] < state.blkIndent
 
         pos = state.bMarks[nextLine] + state.tShift[nextLine]
         max = state.eMarks[nextLine]
@@ -147,20 +146,21 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
             # Case 1: line is not inside the blockquote, and this line is empty.
             break
 
-        evaluatesTrue = state.srcCharCode[pos] == 0x3E and not wasOutdented  # /* > */
+        evaluatesTrue = state.srcCharCode[pos] == 0x3E and not isOutdented  # /* > */
         pos += 1
         if evaluatesTrue:
             # This line is inside the blockquote.
 
-            # skip spaces after ">" and re-calculate offset
-            initial = offset = (
-                state.sCount[nextLine]
-                + pos
-                - (state.bMarks[nextLine] + state.tShift[nextLine])
-            )
+            # set offset past spaces and ">"
+            initial = offset = state.sCount[nextLine] + 1
+
+            try:
+                next_char: Optional[int] = state.srcCharCode[pos]
+            except IndexError:
+                next_char = None
 
             # skip one optional space after '>'
-            if state.srcCharCode[pos] == 0x20:  # /* space */
+            if next_char == 0x20:  # /* space */
                 # ' >   test '
                 #     ^ -- position start of line here:
                 pos += 1
@@ -168,7 +168,7 @@ def blockquote(state: StateBlock, startLine: int, endLine: int, silent: bool):
                 offset += 1
                 adjustTab = False
                 spaceAfterMarker = True
-            elif state.srcCharCode[pos] == 0x09:  # /* tab */
+            elif next_char == 0x09:  # /* tab */
                 spaceAfterMarker = True
 
                 if (state.bsCount[nextLine] + offset) % 4 == 3:
